
#ifndef _C10_ds469_
#define _C10_ds469_

#ifdef __cplusplus
extern "C" {
#endif

extern void F1093_7293(EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit469(void);
extern void F77_1057(EIF_REFERENCE, EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif
